==> circumstellar-0.1.20-dev1.tar.gz: lib/src/models/discord_objects/channels/guild_text_channel.dart <==
part of circumstellar;

class GuildTextChannel extends BaseChannel {
  GuildTextChannel(DiscordClient client) : super(client);

  Future updateModel(Map<String, dynamic> json, DiscordClient client) async {
    this.id = json['id'];
    this.type = json['type'] ?? this.type;
    this.guildId = json['guild_id'] ?? this.guildId;
    this.topic = json['topic'] ?? this.topic;
    this.sortingPosition = json['position'] ?? this.sortingPosition;
    this.name = json['name'] ?? this.name;
    this.isNsfw = json['nsfw'] ?? this.isNsfw;
    this.lastMessageId = json['last_message_id'] ?? this.lastMessageId;
    this.parentCategoryId = json['parent_id'] ?? this.parentCategoryId;

    this.guild =
        (await client.entities.getEntity(json['guild_id'], 'Guild') as Guild) ??
            this.guild;
  }

  // GuildTextChannel properties

  /// The ID of the guild this channel belongs to.
  String guildId = "";

  /// The [Guild] this channel belongs to.
  Guild guild = null;

  /// The position of this guild in the channel list (sorting position)
  int sortingPosition = 1;

  // TODO: Permission overwrites

  /// The name of this channel.
  String name = '';

  /// The topic of this channel.
  String topic = '';

  /// If this channel is NSFW (Not Safe For Work)
  bool isNsfw = false;

  /// The message ID of the last message sent to this channel.
  String lastMessageId = ''; // TODO: Implement this as a Message entity

  /// The ID of the parent category
  String parentCategoryId = '';

  // TODO: Last Pin Timestamps

  Future<RestRequestResult> createMessage(String content,
          {Map<String, dynamic> embed, bool tts, RequestOptions options}) =>
      this.client.createMessage(this.id, content,
          embed: embed, tts: tts, options: options);
}

==> circumstellar-0.1.22.tar.gz: lib/src/models/discord_objects/channels/guild_text_channel.dart <==
/**
 * guild_text_channel.dart
 * Circumstellar - Models/Channel
 * 
 * Created by Jackson Rakena
 * Copyright (c) 2018 Jackson Rakena. All rights reserved.
 * Part of the Circumstellar project, licensed under a 3-Clause BSD License (under LICENSE)
 */

part of circumstellar;

/// Represents a text-supported channel inside of a guild.
class GuildTextChannel extends GuildChannel {
  GuildTextChannel(DiscordClient client) : super(client);

  Future updateModel(Map<String, dynamic> json, DiscordClient client) async {
    await super.updateModel(json, client);
    this.id = json['id'];
    this.type = json['type'] ?? this.type;
    this.topic = json['topic'] ?? this.topic;
    this.sortingPosition = json['position'] ?? this.sortingPosition;
    this.isNsfw = json['nsfw'] ?? this.isNsfw;
    this.lastMessageId = json['last_message_id'] ?? this.lastMessageId;
    this.parentCategoryId = json['parent_id'] ?? this.parentCategoryId;
  }

  // GuildTextChannel properties

  /// The position of this guild in the channel list (sorting position)
  int sortingPosition = 1;

  // TODO: Permission overwrites

  /// The topic of this channel.
  String topic = '';

  /// If this channel is NSFW (Not Safe For Work)
  bool isNsfw = false;

  /// The message ID of the last message sent to this channel.
  String lastMessageId = ''; // TODO: Implement this as a Message entity

  /// The ID of the parent category
  String parentCategoryId = '';

  // TODO: Last Pin Timestamps

  /// Creates a message in this channel.
  Future<Message> createMessage(String content,
          {Map<String, dynamic> embed, bool tts, RequestOptions options}) =>
      this.client.createMessage(this.id, content,
          embed: embed, tts: tts, options: options);
}
